@@ -18,39 +18,42 @@ class Messenger(IMessenger):
         self._command_handlers: Dict[str, ICommandHandler] = dict()
         self._event_handlers: Dict[str, List[IEventHandler]] = dict()
         self._query_handlers: Dict[str, IQueryHandler] = dict()
-        self._tmp_published_events: List[IEvent] = list()
+        self._published_events: List[IEvent] = list()
 
-    def _clear_tmp_published_events(self):
-        self._tmp_published_events = list()
+    def get_published_events(self) -> List[IEvent]:
+        return self._published_events
+
+    def flush_published_events(self) -> None:
+        self._published_events = list()
 
     def publish_command(
         self,
         command: ICommand
-    ) -> List[IEvent]:
-        self._clear_tmp_published_events()
+    ) -> None:
         command_name: str = command.__class__.__name__
         if command_name not in self._command_handlers:
-            raise MissingHandler("Cant publish command {} because no matching handler was found.".format(command))
+            raise MissingHandler(
+                "Publishing command {} failed because of missing subscriber.".format(command))
         command_handler: ICommandHandler = self._command_handlers[command_name]
         command_handler(command)
-        return self._tmp_published_events
 
     def subscribe_command(
         self,
         command_cls: Type[ICommand],
         command_handler: ICommandHandler
-    ):
+    ) -> None:
         command_name: str = command_cls.__name__
         if command_name in self._command_handlers:
-            raise OverwritingHandler("A handler for the command {} already exists.".format(command_name))
+            raise OverwritingHandler(
+                "A handler for the command {} already exists.".format(command_name))
         self._command_handlers[command_name] = command_handler
 
     def publish_event(
         self,
         event: IEvent
-    ):
+    ) -> None:
         event_name: str = event.__class__.__name__
-        self._tmp_published_events.append(event)
+        self._published_events.append(event)
         event_handlers: List[IEventHandler] = \
             self._event_handlers.get(event_name, [])
         for event_handler in event_handlers:
@@ -60,7 +63,7 @@ class Messenger(IMessenger):
         self,
         event_cls: Type[IEvent],
         event_handler: IEventHandler
-    ):
+    ) -> None:
         event_name: str = event_cls.__name__
         if event_name not in self._event_handlers.keys():
             self._event_handlers[event_name] = []
@@ -73,7 +76,8 @@ class Messenger(IMessenger):
     ) -> IResponse:
         query_name: str = query.__class__.__name__
         if query_name not in self._query_handlers:
-            raise MissingHandler("Cant publish query {} because no matching handler was found.".format(query))
+            raise MissingHandler(
+                "Publishing query {} failed because of missing subscriber.".format(query))
         query_handler: IQueryHandler = self._query_handlers[query_name]
         response: IResponse = query_handler(query)
         return response
@@ -82,8 +86,9 @@ class Messenger(IMessenger):
         self,
         query_cls: Type[IQuery],
         query_handler: IQueryHandler
-    ):
+    ) -> None:
         query_name: str = query_cls.__name__
         if query_name in self._query_handlers:
-            raise OverwritingHandler("A handler for the query {} already exists.".format(query_name))
+            raise OverwritingHandler(
+                "A handler for the query {} already exists.".format(query_name))
         self._query_handlers[query_name] = query_handler
